@@ -48,6 +48,7 @@ from ikabot.helpers.gui import *
 from ikabot.helpers.pedirInfo import read
 from ikabot.helpers.process import updateProcessList
 from ikabot.web.session import *
+from ikabot.function.modifyProduction import modifyProduction
 
 
 def menu(session, checkUpdate=True):
@@ -147,6 +148,7 @@ def menu(session, checkUpdate=True):
         2107: importExportCookie,
         2108: loadCustomModule,
         22: consolidateResources,
+        23: modifyProduction
     }
 
     print("(0)  Exit")
@@ -172,6 +174,8 @@ def menu(session, checkUpdate=True):
     print("(20) Dump / Monitor world")
     print("(21) Options / Settings")
     print("(22) Consolidate resources")
+    print("(23) Set Production of Saw mill / Luxury good")
+
     total_options = len(menu_actions) + 1
     selected = read(min=0, max=total_options, digit=True, empty=True)
     
